@@ -62,6 +62,7 @@ SCH_DRAWING_TOOLS::SCH_DRAWING_TOOLS() :
         m_lastTextOrientation( LABEL_SPIN_STYLE::RIGHT ),
         m_lastTextBold( false ),
         m_lastTextItalic( false ),
+        m_mruPath( wxEmptyString ),
         m_inPlaceSymbol( false ),
         m_inPlaceImage( false ),
         m_inSingleClickPlace( false ),
@@ -128,7 +129,7 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
     }
     else
     {
-        wxFAIL_MSG( "PlaceSymbol(): unexpected request" );
+        wxFAIL_MSG( wxT( "PlaceSymbol(): unexpected request" ) );
     }
 
     std::string tool = aEvent.GetCommandStr().get();
@@ -278,12 +279,14 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                     symbol->AutoplaceFields( /* aScreen */ nullptr, /* aManual */ false );
 
                 symbol->ClearEditFlags();
+                m_view->Update( symbol );
+                m_frame->GetScreen()->Update( symbol );
 
+                m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true,
+                                      &m_selectionTool->GetSelection() );
                 m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true,
                                       &m_selectionTool->GetSelection() );
 
-                m_view->Update( symbol );
-                m_frame->GetScreen()->Update( symbol );
                 m_frame->OnModify();
 
                 SCH_SYMBOL* nextSymbol = nullptr;
@@ -487,7 +490,7 @@ int SCH_DRAWING_TOOLS::PlaceImage( const TOOL_EVENT& aEvent )
                 // having an auto-pan
                 EDA_RECT canvas_area = GetCanvasFreeAreaPixels();
 
-                wxFileDialog dlg( m_frame, _( "Choose Image" ), wxEmptyString, wxEmptyString,
+                wxFileDialog dlg( m_frame, _( "Choose Image" ), m_mruPath, wxEmptyString,
                                   _( "Image Files" ) + wxS( " " ) + wxImage::GetImageExtWildcard(),
                                   wxFD_OPEN );
 
@@ -508,6 +511,7 @@ int SCH_DRAWING_TOOLS::PlaceImage( const TOOL_EVENT& aEvent )
                 cursorPos = controls->GetMousePosition( true );
 
                 wxString fullFilename = dlg.GetPath();
+                m_mruPath = wxPathOnly( fullFilename );
 
                 if( wxFileExists( fullFilename ) )
                     image = new SCH_BITMAP( (wxPoint)cursorPos );
@@ -654,7 +658,7 @@ int SCH_DRAWING_TOOLS::SingleClickPlace( const TOOL_EVENT& aEvent )
         break;
 
     default:
-        wxASSERT_MSG( false, "Unknown item type in SCH_DRAWING_TOOLS::SingleClickPlace" );
+        wxASSERT_MSG( false, wxT( "Unknown item type in SCH_DRAWING_TOOLS::SingleClickPlace" ) );
         return 0;
     }
 
@@ -889,7 +893,7 @@ SCH_TEXT* SCH_DRAWING_TOOLS::createNewText( const VECTOR2I& aPosition, int aType
         break;
 
     default:
-        wxFAIL_MSG( "SCH_EDIT_FRAME::CreateNewText() unknown layer type" );
+        wxFAIL_MSG( wxT( "SCH_EDIT_FRAME::CreateNewText() unknown layer type" ) );
         return nullptr;
     }
 
@@ -1340,8 +1344,8 @@ int SCH_DRAWING_TOOLS::DrawSheet( const TOOL_EVENT& aEvent )
             sheet->SetBorderWidth( Mils2iu( cfg->m_Drawing.default_line_thickness ) );
             sheet->SetBorderColor( cfg->m_Drawing.default_sheet_border_color );
             sheet->SetBackgroundColor( cfg->m_Drawing.default_sheet_background_color );
-            sheet->GetFields()[ SHEETNAME ].SetText( "Untitled Sheet" );
-            sheet->GetFields()[ SHEETFILENAME ].SetText( "untitled." + KiCadSchematicFileExtension );
+            sheet->GetFields()[ SHEETNAME ].SetText( wxT( "Untitled Sheet" ) );
+            sheet->GetFields()[ SHEETFILENAME ].SetText( wxT( "untitled." ) + KiCadSchematicFileExtension );
             sizeSheet( sheet, cursorPos );
 
             m_view->ClearPreview();
@@ -1370,7 +1374,7 @@ int SCH_DRAWING_TOOLS::DrawSheet( const TOOL_EVENT& aEvent )
                 SCH_SHEET_PATH sheetPath = instance;
                 sheetPath.push_back( sheet );
                 sheet->AddInstance( sheetPath );
-                sheet->SetPageNumber( sheetPath, wxString::Format( "%d", pageNum++ ) );
+                sheet->SetPageNumber( sheetPath, wxString::Format( wxT( "%d" ), pageNum++ ) );
             }
 
             if( m_frame->EditSheetProperties( static_cast<SCH_SHEET*>( sheet ),
