@@ -133,9 +133,18 @@ int SCH_EDITOR_CONTROL::PageSetup( const TOOL_EVENT& aEvent )
     dlg.SetWksFileName( BASE_SCREEN::m_DrawingSheetFileName );
 
     if( dlg.ShowModal() )
+    {
+        // Update text variables
+        m_frame->GetCanvas()->GetView()->MarkDirty();
+        m_frame->GetCanvas()->GetView()->UpdateAllItems( KIGFX::REPAINT );
+        m_frame->GetCanvas()->Refresh();
+
         m_frame->OnModify();
+    }
     else
+    {
         m_frame->RollbackSchematicFromUndo();
+    }
 
     return 0;
 }
@@ -550,6 +559,10 @@ int SCH_EDITOR_CONTROL::ReplaceAndFindNext( const TOOL_EVENT& aEvent )
 
     if( item && item->Matches( data, sheet ) )
     {
+        SCH_ITEM* sch_item = static_cast<SCH_ITEM*>( item );
+
+        m_frame->SaveCopyInUndoList( sheet->LastScreen(), sch_item, UNDO_REDO::CHANGED, false );
+
         if( item->Replace( data, sheet ) )
         {
             m_frame->UpdateItem( item, false, true );
@@ -576,6 +589,9 @@ int SCH_EDITOR_CONTROL::ReplaceAll( const TOOL_EVENT& aEvent )
     auto doReplace =
             [&]( SCH_ITEM* aItem, SCH_SHEET_PATH* aSheet, wxFindReplaceData& aData )
             {
+                m_frame->SaveCopyInUndoList( aSheet->LastScreen(), aItem, UNDO_REDO::CHANGED,
+                                             modified );
+
                 if( aItem->Replace( aData, aSheet ) )
                 {
                     m_frame->UpdateItem( aItem, false, true );
@@ -780,9 +796,9 @@ int SCH_EDITOR_CONTROL::SimProbe( const TOOL_EVENT& aEvent )
                     primitive = NETLIST_EXPORTER_PSPICE::GetSpiceField( SF_PRIMITIVE, symbol, 0 );
                     primitive.LowerCase();
 
-                    if( primitive == "c" || primitive == "l" || primitive == "r" )
+                    if( primitive == wxT( "c" ) || primitive == wxT( "l" ) || primitive == wxT( "r" ) )
                         param = wxT( "I" );
-                    else if( primitive == "d" )
+                    else if( primitive == wxT( "d" ) )
                         param = wxT( "Id" );
                     else
                         param = wxString::Format( wxT( "I%s" ), pin->GetShownName().Lower() );
@@ -998,7 +1014,7 @@ static bool highlightNet( TOOL_MANAGER* aToolMgr, const VECTOR2D& aPosition )
 
     if( !conn )
     {
-        editFrame->SetStatusText( wxT( "" ) );
+        editFrame->SetStatusText( wxEmptyString );
         editFrame->SendCrossProbeClearHighlight();
     }
     else
@@ -1550,7 +1566,7 @@ SCH_SHEET_PATH SCH_EDITOR_CONTROL::updatePastedSheet( const SCH_SHEET_PATH& aPas
     if( m_clipboardSheetInstances.count( aClipPath ) > 0 )
         pageNum = m_clipboardSheetInstances.at( aClipPath ).m_PageNumber;
     else
-        pageNum = wxString::Format( "%d", static_cast<int>( aPastedSheetsSoFar->size() ) );
+        pageNum = wxString::Format( wxT( "%d" ), static_cast<int>( aPastedSheetsSoFar->size() ) );
 
     aSheet->SetPageNumber( sheetPath, pageNum );
     aPastedSheetsSoFar->push_back( sheetPath );
@@ -1920,10 +1936,10 @@ int SCH_EDITOR_CONTROL::Paste( const TOOL_EVENT& aEvent )
             for( SCH_SHEET_PATH& pastedSheet : pastedSheets[instance] )
             {
                 int      page = 1;
-                wxString pageNum = wxString::Format( "%d", page );
+                wxString pageNum = wxString::Format( wxT( "%d" ), page );
 
                 while( hierarchy.PageNumberExists( pageNum ) )
-                    pageNum = wxString::Format( "%d", ++page );
+                    pageNum = wxString::Format( wxT( "%d" ), ++page );
 
                 pastedSheet.SetPageNumber( pageNum );
                 hierarchy.push_back( pastedSheet );
