@@ -88,6 +88,7 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
     KIGFX::VIEW_CONTROLS* controls = getViewControls();
     EE_GRID_HELPER        grid( m_toolMgr );
     bool                  wasDragging = m_moveInProgress && m_isDrag;
+    SCH_MOVE_TOOL_PARAMS* params = aEvent.Parameter<SCH_MOVE_TOOL_PARAMS*>();
 
     m_anchorPos.reset();
 
@@ -174,8 +175,11 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
             if( !m_moveInProgress )    // Prepare to start moving/dragging
             {
                 SCH_ITEM* sch_item = (SCH_ITEM*) selection.Front();
-                bool      appendUndo = sch_item && sch_item->IsNew();
-                bool      placingNewItems = sch_item && sch_item->IsNew();
+                bool      appendUndo =
+                        params ? params->appendToLastUndo : ( sch_item && sch_item->IsNew() );
+                bool placingNewItems =
+                        params ? params->placingNewItems : ( sch_item && sch_item->IsNew() );
+
 
                 //------------------------------------------------------------------------
                 // Setup a drag or a move
@@ -283,7 +287,7 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
 
                 if( evt->IsAction( &EE_ACTIONS::restartMove ) )
                 {
-                    wxASSERT_MSG( m_anchorPos, "Should be already set from previous cmd" );
+                    wxASSERT_MSG( m_anchorPos, wxT( "Should be already set from previous cmd" ) );
                 }
                 else if( placingNewItems )
                 {
@@ -446,6 +450,11 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
                 }
             }
         }
+        else if( evt->IsAction( &EE_ACTIONS::highlightNet )
+                    || evt->IsAction( &EE_ACTIONS::explicitCrossProbe ) )
+        {
+            // These don't make any sense during a move.  Eat them.
+        }
         //------------------------------------------------------------------------
         // Handle context menu
         //
@@ -505,6 +514,7 @@ int SCH_MOVE_TOOL::Main( const TOOL_EVENT& aEvent )
                 m_frame->AddJunction( m_frame->GetScreen(), it.GetPosition(), true, false );
         }
 
+        m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true, &selectionCopy );
         m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true, &selectionCopy );
 
         m_frame->RecalculateConnections( LOCAL_CLEANUP );
@@ -917,6 +927,7 @@ int SCH_MOVE_TOOL::AlignElements( const TOOL_EVENT& aEvent )
     }
 
     m_toolMgr->PostEvent( EVENTS::SelectedItemsMoved );
+    m_toolMgr->RunAction( EE_ACTIONS::trimOverlappingWires, true, &selection );
     m_toolMgr->RunAction( EE_ACTIONS::addNeededJunctions, true, &selection );
 
     m_frame->RecalculateConnections( LOCAL_CLEANUP );
