@@ -492,9 +492,6 @@ bool PCB_VIA::FlashLayer( LSET aLayers ) const
 
 bool PCB_VIA::FlashLayer( int aLayer ) const
 {
-    std::vector<KICAD_T> types
-    { PCB_TRACE_T, PCB_ARC_T, PCB_PAD_T, PCB_ZONE_T, PCB_FP_ZONE_T };
-
     // Return the "normal" shape if the caller doesn't specify a particular layer
     if( aLayer == UNDEFINED_LAYER )
         return true;
@@ -513,7 +510,11 @@ bool PCB_VIA::FlashLayer( int aLayer ) const
     if( m_keepTopBottomLayer && ( aLayer == m_layer || aLayer == m_bottomLayer ) )
         return true;
 
-    return board->GetConnectivity()->IsConnectedOnLayer( this, static_cast<int>( aLayer ), types );
+    // Must be static to keep from raising its ugly head in performance profiles
+    static std::vector<KICAD_T> connectedTypes = { PCB_TRACE_T, PCB_ARC_T, PCB_PAD_T,
+                                                   PCB_ZONE_T, PCB_FP_ZONE_T };
+
+    return board->GetConnectivity()->IsConnectedOnLayer( this, aLayer, connectedTypes, true );
 }
 
 
@@ -604,6 +605,20 @@ double PCB_VIA::ViewGetLOD( int aLayer, KIGFX::VIEW* aView ) const
     if( board )
         visible = board->GetVisibleLayers() & board->GetEnabledLayers();
 
+    // In high contrast mode don't show vias that don't cross the high-contrast layer
+    if( renderSettings->GetHighContrast() )
+    {
+        PCB_LAYER_ID highContrastLayer = renderSettings->GetPrimaryHighContrastLayer();
+
+        if( LSET::FrontTechMask().Contains( highContrastLayer ) )
+            highContrastLayer = F_Cu;
+        else if( LSET::BackTechMask().Contains( highContrastLayer ) )
+            highContrastLayer = B_Cu;
+
+        if( !GetLayerSet().Contains( highContrastLayer ) )
+            return HIDE;
+    }
+
     if( IsViaPadLayer( aLayer ) )
     {
         if( !FlashLayer( visible ) )
@@ -656,7 +671,7 @@ void PCB_TRACK::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_I
     BOARD*    board = GetBoard();
 
     aList.emplace_back( _( "Type" ),
-                        Type() == PCB_ARC_T ? ( "Track (arc)" ) : _( "Track" ) );
+                        Type() == PCB_ARC_T ? _( "Track (arc)" ) : _( "Track" ) );
 
 
     GetMsgPanelInfoBase_Common( aFrame, aList );
@@ -1018,7 +1033,7 @@ void PCB_TRACK::TransformShapeWithClearanceToPolygon( SHAPE_POLY_SET& aCornerBuf
                                                       int aError, ERROR_LOC aErrorLoc,
                                                       bool ignoreLineWidth ) const
 {
-    wxASSERT_MSG( !ignoreLineWidth, "IgnoreLineWidth has no meaning for tracks." );
+    wxASSERT_MSG( !ignoreLineWidth, wxT( "IgnoreLineWidth has no meaning for tracks." ) );
 
 
     switch( Type() )
