@@ -249,12 +249,6 @@ void ZONE::SetLayer( PCB_LAYER_ID aLayer )
 
 void ZONE::SetLayerSet( LSET aLayerSet )
 {
-    if( GetIsRuleArea() )
-    {
-        // Rule areas can only exist on copper layers
-        aLayerSet &= LSET::AllCuMask();
-    }
-
     if( aLayerSet.count() == 0 )
         return;
 
@@ -598,7 +592,7 @@ void ZONE::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_ITEM>&
         }
 
         // Display priority level
-        aList.emplace_back( _( "Priority" ), wxString::Format( "%d", GetPriority() ) );
+        aList.emplace_back( _( "Priority" ), wxString::Format( wxT( "%d" ), GetPriority() ) );
     }
 
     if( aFrame->GetName() == PCB_EDIT_FRAME_NAME )
@@ -653,32 +647,6 @@ void ZONE::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_ITEM>&
     // and filled polygons can explain the display and DRC calculation time:
     msg.Printf( wxT( "%d" ), (int) m_borderHatchLines.size() );
     aList.emplace_back( MSG_PANEL_ITEM( _( "HatchBorder Lines" ), msg ) );
-
-    PCB_LAYER_ID layer = m_layer;
-
-    // NOTE: This brings in dependence on PCB_EDIT_FRAME to the qa tests, which isn't ideal.
-    // TODO: Figure out a way for items to know the active layer without the whole edit frame?
-#if 0
-    if( PCB_EDIT_FRAME* pcbframe = dynamic_cast<PCB_EDIT_FRAME*>( aFrame ) )
-    {
-        if( m_FilledPolysList.count( pcbframe->GetActiveLayer() ) )
-            layer = pcbframe->GetActiveLayer();
-    }
-#endif
-
-    if( !GetIsRuleArea() )
-    {
-        auto layer_it = m_FilledPolysList.find( layer );
-
-        if( layer_it == m_FilledPolysList.end() )
-            layer_it = m_FilledPolysList.begin();
-
-        if( layer_it != m_FilledPolysList.end() )
-        {
-            msg.Printf( wxT( "%d" ), layer_it->second.TotalVertices() );
-            aList.emplace_back( MSG_PANEL_ITEM( _( "Corner Count" ), msg ) );
-        }
-    }
 }
 
 
@@ -749,10 +717,7 @@ void ZONE::Flip( const wxPoint& aCentre, bool aFlipLeftRight )
     Mirror( aCentre, aFlipLeftRight );
     int copperLayerCount = GetBoard()->GetCopperLayerCount();
 
-    if( GetIsRuleArea() )
-        SetLayerSet( FlipLayerMask( GetLayerSet(), copperLayerCount ) );
-    else
-        SetLayer( FlipLayer( GetLayer(), copperLayerCount ) );
+    SetLayerSet( FlipLayerMask( GetLayerSet(), copperLayerCount ) );
 }
 
 
@@ -1184,7 +1149,7 @@ bool ZONE::BuildSmoothedPoly( SHAPE_POLY_SET& aSmoothedPoly, PCB_LAYER_ID aLayer
         return false;
 
     // Processing of arc shapes in zones is not yet supported because Clipper can't do boolean
-    // operations on them.  The poly outline must be flattened first.
+    // operations on them.  The poly outline must be converted to segments first.
     SHAPE_POLY_SET flattened = *m_Poly;
     flattened.ClearArcs();
 
@@ -1298,6 +1263,7 @@ double ZONE::CalculateFilledArea()
 
 
 void ZONE::TransformSmoothedOutlineToPolygon( SHAPE_POLY_SET& aCornerBuffer, int aClearance,
+                                              int aMaxError, ERROR_LOC aErrorLoc,
                                               SHAPE_POLY_SET* aBoardOutline ) const
 {
     // Creates the zone outline polygon (with holes if any)
@@ -1315,6 +1281,10 @@ void ZONE::TransformSmoothedOutlineToPolygon( SHAPE_POLY_SET& aCornerBuffer, int
             maxError = board->GetDesignSettings().m_MaxError;
 
         int segCount = GetArcToSegmentCount( aClearance, maxError, 360.0 );
+
+        if( aErrorLoc == ERROR_OUTSIDE )
+            aClearance += aMaxError;
+
         polybuffer.Inflate( aClearance, segCount );
     }
 
@@ -1347,7 +1317,7 @@ FP_ZONE::FP_ZONE( BOARD_ITEM_CONTAINER* aParent ) :
 
 
 FP_ZONE::FP_ZONE( const FP_ZONE& aZone ) :
-        ZONE( aZone.GetParent(), true )
+        ZONE( aZone )
 {
     InitDataFromSrcInCopyCtor( aZone );
 }
@@ -1411,16 +1381,23 @@ void ZONE::TransformShapeWithClearanceToPolygon( SHAPE_POLY_SET& aCornerBuffer,
                                                  PCB_LAYER_ID aLayer, int aClearance, int aError,
                                                  ERROR_LOC aErrorLoc, bool aIgnoreLineWidth ) const
 {
-    wxASSERT_MSG( !aIgnoreLineWidth, "IgnoreLineWidth has no meaning for zones." );
+    wxASSERT_MSG( !aIgnoreLineWidth, wxT( "IgnoreLineWidth has no meaning for zones." ) );
 
     if( !m_FilledPolysList.count( aLayer ) )
         return;
 
     aCornerBuffer = m_FilledPolysList.at( aLayer );
 
-    int numSegs = GetArcToSegmentCount( aClearance, aError, 360.0 );
-    aCornerBuffer.Inflate( aClearance, numSegs );
-    aCornerBuffer.Simplify( SHAPE_POLY_SET::PM_STRICTLY_SIMPLE );
+    // Rebuild filled areas only if clearance is not 0
+    if( aClearance )
+    {
+        int numSegs = GetArcToSegmentCount( aClearance, aError, 360.0 );
+
+        if( aErrorLoc == ERROR_OUTSIDE )
+            aClearance += aError;
+
+        aCornerBuffer.InflateWithLinkedHoles( aClearance, numSegs, SHAPE_POLY_SET::PM_FAST );
+    }
 }
 
 
